@@ -3,6 +3,9 @@ package Perlanet;
 use strict;
 use warnings;
 
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose;
 use namespace::autoclean;
 
@@ -15,12 +18,6 @@ use Try::Tiny;
 use URI::Fetch;
 use XML::Feed;
 
-use vars qw{$VERSION};
-
-BEGIN {
-  $VERSION = '0.57';
-}
-
 with 'MooseX::Traits';
 
 $XML::Atom::ForceUnicode = 1;
