@@ -1,4 +1,11 @@
 package Perlanet::Entry;
+
+use strict;
+use warnings;
+
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose;
 
 =head1 NAME
@@ -16,7 +23,7 @@ has '_entry' => (
   isa => 'XML::Feed::Entry',
   is => 'ro',
   required => 1,
-  handles => [qw( title link issued body summary content modified )]
+  handles => [qw( title link issued body summary content modified author )]
 );
 
 has 'feed' => (
