@@ -1,4 +1,11 @@
 package Perlanet::Feed;
+
+use strict;
+use warnings;
+
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose;
 use XML::Feed;
 
@@ -18,7 +25,7 @@ has 'url' => (
   is => 'rw',
 );
 
-has 'website' => (
+has 'web' => (
   isa => 'Str',
   is => 'rw',
 );
