@@ -3,6 +3,9 @@ package Perlanet::Simple;
 use strict;
 use warnings;
 
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose;
 use namespace::autoclean;
 
@@ -11,14 +14,14 @@ use YAML 'LoadFile';
 
 extends 'Perlanet';
 with qw(
-    Perlanet::Trait::Cache
-    Perlanet::Trait::OPML
-    Perlanet::Trait::Scrubber
-    Perlanet::Trait::Tidy
-    Perlanet::Trait::YAMLConfig
-    Perlanet::Trait::TemplateToolkit
-    Perlanet::Trait::FeedFile
-   );
+  Perlanet::Trait::Cache
+  Perlanet::Trait::OPML
+  Perlanet::Trait::Scrubber
+  Perlanet::Trait::Tidy
+  Perlanet::Trait::YAMLConfig
+  Perlanet::Trait::TemplateToolkit
+  Perlanet::Trait::FeedFile
+);
 
 =head1 NAME
 
@@ -26,8 +29,12 @@ Perlanet::Simple - a DWIM Perlanet
 
 =head1 SYNOPSIS
 
-    my $perlanet = Perlanet::Simple->new_with_config('perlanet.yaml')
-    $perlanet->run
+  use Perlanet::Simple;
+
+  my $perlanet = Perlanet::Simple->new_with_config(
+    configfile => 'perlanet.yaml'
+  );
+  $perlanet->run;
 
 =head1 DESCRIPTION
 
