@@ -1,4 +1,11 @@
 package Perlanet::Trait::OPML;
+
+use strict;
+use warnings;
+
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose::Role;
 use namespace::autoclean;
 
