@@ -3,6 +3,9 @@ package Perlanet::Trait::Scrubber;
 use strict;
 use warnings;
 
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose::Role;
 use namespace::autoclean;
 
