@@ -1,4 +1,11 @@
 package Perlanet::Trait::TemplateToolkit;
+
+use strict;
+use warnings;
+
+use 5.6.0;
+our $VERSION = '0.58';
+
 use Moose::Role;
 use namespace::autoclean;
 
@@ -57,6 +64,7 @@ after 'render' => sub {
     $self->page->{template},
     {
       feed => $feed,
+      cfg  => $self,
     },
     $self->page->{file},
     {
